@@ -16,24 +16,43 @@ def _flush_output():
 
 
 def run_autodetect():
+    ###
+    # Enabling Conan download cache
+    ###
     printer.print_message("Enabling Conan download cache ...")
 
     tmpdir = os.path.join(tempfile.gettempdir(), "conan")
 
     os.makedirs(tmpdir, mode=0o777)
+    # In some cases Python may ignore the mode of makedirs, do it again explicitly with chmod
+    os.chmod(tmpdir, mode=0o777)
 
     os.system('conan config set storage.download_cache="{}"'.format(tmpdir))
-    os.environ["CONAN_DOCKER_ENTRY_SCRIPT"] = 'conan config set storage.download_cache="{}"'.format(tmpdir)
-    os.environ["CONAN_DOCKER_RUN_OPTIONS"] = '-v "{}":"/tmp/conan"'.format(tmpdir)
+    os.environ["CONAN_DOCKER_ENTRY_SCRIPT"] = "conan config set storage.download_cache='{}'".format(tmpdir)
+    os.environ["CONAN_DOCKER_RUN_OPTIONS"] = "-v '{}':'/tmp/conan'".format(tmpdir)
 
+    ###
+    # Enabling installing system_requirements
+    ###
+    os.environ["CONAN_SYSREQUIRES_MODE"] = "enabled"
+
+    ###
+    # Detect and execute custom build.py file if existing
+    ###
     has_custom_build_py, custom_build_py_path = is_custom_build_py_existing()
 
     if has_custom_build_py:
         printer.print_message("Custom build.py detected. Executing ...")
         _flush_output()
-        subprocess.run(["python",  "{}".format(custom_build_py_path)], check=True)
+        new_wd = os.path.dirname(custom_build_py_path)
+        if new_wd == "":
+            new_wd = "."
+        subprocess.run("cd {} && python build.py".format(new_wd), shell=True, check=True)
         return
 
+    ###
+    # Output collected recipe information in the builds logs
+    ###
     recipe_is_installer = is_installer()
     printer.print_message("Is the package an installer for executable(s)? {}"
                           .format(str(recipe_is_installer)))
@@ -53,15 +72,24 @@ def run_autodetect():
 
     _flush_output()
 
+    ###
+    # Start the build
+    ###
+    kwargs = {}
+
+    if autodetect_directory_structure() == DIR_STRUCTURE_ONE_RECIPE_MANY_VERSIONS \
+            or autodetect_directory_structure() == DIR_STRUCTURE_CCI:
+        kwargs["stable_branch_pattern"] = os.getenv("CONAN_STABLE_BRANCH_PATTERN", "main")
+
     if recipe_is_installer:
         arch = os.getenv("ARCH", "x86_64")
-        builder = build_template_installer.get_builder()
+        builder = build_template_installer.get_builder(**kwargs)
         builder.add({"os": get_os(), "arch_build": arch, "arch": arch}, {}, {}, {})
         builder.run()
     elif recipe_is_unconditional_header_only:
-        builder = build_template_header_only.get_builder()
+        builder = build_template_header_only.get_builder(**kwargs)
         builder.run()
     else:
-        builder = build_template_default.get_builder(pure_c=recipe_is_pure_c)
+        builder = build_template_default.get_builder(pure_c=recipe_is_pure_c, **kwargs)
         builder.run()
 
